@@ -1,11 +1,13 @@
-# azurerm restfns - REST functions for azurerm
-import json
+'''azurerm restfns - REST functions for azurerm'''
+import platform
+
+import pkg_resources  # to get version
 import requests
-import pkg_resources # to get version
-import platform 
+
 
-# User-Agent Header
 def get_user_agent():
+    '''User-Agent Header. Sends library identification to Azure endpoint.
+    '''
     version = pkg_resources.require("azurerm")[0].version
     user_agent = "python/{} ({}) requests/{} azurerm/{}".format(
         platform.python_version(),
@@ -14,25 +16,38 @@ def get_user_agent():
         version)
     return user_agent
 
-# do_get(endpoint, access_token)
-# do an HTTP GET request and return JSON
 def do_get(endpoint, access_token):
+    '''Do an HTTP GET request and return JSON.
+
+    Args:
+        endpoint (str): Azure Resource Manager management endpoint.
+        access_token (str): A valid Azure authentication token.
+
+    Returns:
+        HTTP response. JSON body.
+    '''
     headers = {"Authorization": 'Bearer ' + access_token}
     headers['User-Agent'] = get_user_agent()
     return requests.get(endpoint, headers=headers).json()
 
 
-# do_get_next(endpoint, access_token)
-# do an HTTP GET request, follow the nextLink chain and return JSON
 def do_get_next(endpoint, access_token):
+    '''Do an HTTP GET request, follow the nextLink chain and return JSON.
+
+    Args:
+        endpoint (str): Azure Resource Manager management endpoint.
+        access_token (str): A valid Azure authentication token.
+
+    Returns:
+        HTTP response. JSON body.
+    '''
     headers = {"Authorization": 'Bearer ' + access_token}
     headers['User-Agent'] = get_user_agent()
     looping = True
     value_list = []
     vm_dict = {}
-    while(looping):
+    while looping:
         get_return = requests.get(endpoint, headers=headers).json()
-        # print(json.dumps(get_return[get_return, sort_keys=False, indent=2, separators=(',', ': ')))
         if not 'value' in get_return:
             return get_return
         if not 'nextLink' in get_return:
@@ -44,33 +59,64 @@ def do_get_next(endpoint, access_token):
     return vm_dict
 
 
-# do_delete(endpoint, access_token)
-# do an HTTP GET request and return JSON
 def do_delete(endpoint, access_token):
+    '''Do an HTTP GET request and return JSON.
+
+    Args:
+        endpoint (str): Azure Resource Manager management endpoint.
+        access_token (str): A valid Azure authentication token.
+
+    Returns:
+        HTTP response.
+    '''
     headers = {"Authorization": 'Bearer ' + access_token}
     headers['User-Agent'] = get_user_agent()
     return requests.delete(endpoint, headers=headers)
 
 
-# do_patch(endpoint, body, access_token)
-# do an HTTP PATCH request and return JSON
 def do_patch(endpoint, body, access_token):
+    '''Do an HTTP PATCH request and return JSON.
+
+    Args:
+        endpoint (str): Azure Resource Manager management endpoint.
+        body (str): JSON body of information to patch.
+        access_token (str): A valid Azure authentication token.
+
+    Returns:
+        HTTP response. JSON body.
+    '''
     headers = {"content-type": "application/json", "Authorization": 'Bearer ' + access_token}
     headers['User-Agent'] = get_user_agent()
     return requests.patch(endpoint, data=body, headers=headers)
 
 
-# do_post(endpoint, body, access_token)
-# do an HTTP POST request and return JSON
 def do_post(endpoint, body, access_token):
+    '''Do an HTTP POST request and return JSON.
+
+    Args:
+        endpoint (str): Azure Resource Manager management endpoint.
+        body (str): JSON body of information to post.
+        access_token (str): A valid Azure authentication token.
+
+    Returns:
+        HTTP response. JSON body.
+    '''
     headers = {"content-type": "application/json", "Authorization": 'Bearer ' + access_token}
     headers['User-Agent'] = get_user_agent()
     return requests.post(endpoint, data=body, headers=headers)
 
 
-# do_put(endpoint, body, access_token)
-# do an HTTP PUT request and return JSON
 def do_put(endpoint, body, access_token):
+    '''Do an HTTP PUT request and return JSON.
+
+    Args:
+        endpoint (str): Azure Resource Manager management endpoint.
+        body (str): JSON body of information to put.
+        access_token (str): A valid Azure authentication token.
+
+    Returns:
+        HTTP response. JSON body.
+    '''
     headers = {"content-type": "application/json", "Authorization": 'Bearer ' + access_token}
     headers['User-Agent'] = get_user_agent()
-    return requests.put(endpoint, data=body, headers=headers)
\ No newline at end of file
+    return requests.put(endpoint, data=body, headers=headers)
