@@ -1,4 +1,4 @@
-# settings.py - place to store constants for azurerm
+'''settings.py - place to store constants for azurerm'''
 import os
 
 # public defaults for authentication and resource endpoints
@@ -17,9 +17,13 @@ MEDIA_API = '2015-10-01'
 NETWORK_API = '2017-04-01'
 STORAGE_API = '2016-01-01'
 
-# Isolated cloud support..
-# allow Azure endpoints to bet set by environment variable, else return default values
 def get_rm_endpoint():
+    '''Set Azure Resource Manager endpoint by environment variable, else return default value.
+
+    These functions facilitate the use of national and isolated clouds by allowing endpoints to
+    be set dynamically. The default settings, if no environment varibles are used,
+    are for public cloud.
+    '''
     rm_endpoint = os.environ.get('AZURE_RM_ENDPOINT')
     if rm_endpoint is None:
         return AZURE_RM_ENDPOINT
@@ -28,6 +32,8 @@ def get_rm_endpoint():
 
 
 def get_auth_endpoint():
+    '''Set Azure auth endpoint by environment variable, else return default value.
+    '''
     auth_endpoint = os.environ.get('AZURE_AUTH_ENDPOINT')
     if auth_endpoint is None:
         return AZURE_AUTH_ENDPOINT
@@ -36,6 +42,8 @@ def get_auth_endpoint():
 
 
 def get_resource_endpoint():
+    '''Set Azure reousrce endpoint by environment variable, else return default value.
+    '''
     resource_endpoint = os.environ.get('AZURE_RESOURCE_ENDPOINT')
     if resource_endpoint is None:
         return AZURE_RESOURCE_ENDPOINT
